==============
cuebung_helper
==============


Helper function to test c code with pytest

.. image:: https://codecov.io/gl/cuebung/cuebung_helper_functions/branch/master/graph/badge.svg?token=GNnCaLGieF
  :target: https://codecov.io/gl/cuebung/cuebung_helper_functions
  
.. image:: https://gitlab.com/cuebung/cuebung_helper_functions/badges/master/build.svg
  :target: https://gitlab.com/cuebung/cuebung_helper_functions
  
Description
===========

Helper function to test c code with pytest and provide an interface to present 
the results on the web frontend

Note
====

This project has been set up using PyScaffold 2.5.6. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
